---
Title: MM alerts
Author: Feifei
status: dump
---

## Overview of Multi-Messenger Astrophysics

The Multi-messenger approach in astrophysics means looking for at least two or more cosmic messenger particles to study the transient phenomena in our universe, such as gamma-ray burst, the outburst of active galactic nuclei, fast radio burst, supernova explosion, etc. Using multiple messengers greatly extends our understanding of the universe compared to using one single channel. The cosmic messengers include electromagnetic waves, cosmic rays, gravitational waves, and neutrinos. 

Some of the most important open questions in astrophysics are the origin of astrophysical neutrinos, the origin of cosmic rays, acceleration mechanics of high energy cosmic rays, etc. Multi-messenger studies can help answer these questions.

Up to now, there are three successful multi-messenger detections: 1) In 1987, the observation of the supernova 1987A, where neutrinos are observed in neutrino experiments about 2 or 3 hours before the visual observations. 2) 30 years later in 2017, the observation of the gravitational wave and the electromagnetic observations of the gamma-ray burst observed by Fermi and Integral. 3) TXS 0506, where for the first time, blazars are identified as one neutrino source. 

## Importance of Neutrinos for Multi-Messenger Studies

Among those multiple messengers, neutrinos are an important type of messenger. Neutrinos are neutral and only interact via gravity and weak interactions. Neutrinos point back to their sources where they were created.

For example, cosmic rays are charged particles, thus they are deflected by the galactic magnetic fields. Cosmic ray observatories can detect them but their observed arrival directions do not point back to their sources. During the propagation of cosmic rays, neutrinos are produced during the interaction of cosmic rays and the extragalactic background light. Since neutrinos are not bent by magnetic fields, they can act as good tracers for studying the propagation of cosmic rays.

Looking for coincidences of neutrinos and electromagnetic or GW counterparts may also reveal subthreshold events that otherwise do not generate interest within each single observatory, or even reveal new sources.

Because neutrinos travel with nearly the speed of the light, a real-time or near real-time alert system based on neutrinos (with a good angular resolution) is possible. It is vital for follow-ups for some high energy transient sources that are time-dependent with the flux quickly varying. For example, a real-time neutrino alert will be able to point to a direction for space electromagnetic observatories that have a small sky coverage (e.g. Fermi-LAT) to conduct their search in a timely fashion. 

## KM3NeT Multi-Messenger Neutrino Alerts

KM3NeT is a multi-purpose cubic-kilometer neutrino observatory currently being deployed at the bottom of the Mediterranean Sea. The detector is 3-d arrays of light sensors called digital optical modules (DOMs), each DOM consist of 31 PMTs that can detect light signals. KM3NeT detects neutrinos via the Cherenkov technique: neutrinos have weak interactions in the seawater and produce secondary particles that emit Cherenkov light while traveling in the seawater with a speed larger than the light phase speed in seawater. So even though neutrinos are not directly observed, the spatial and temporal distributions of the light and the amount of light observed by the DOMs can be used to reconstruct the incoming neutrinos' direction and energy.

KM3NeT consists of two detectors: ORCA (Oscillation Research with Cosmics in the Abyss) and ARCA (Astroparticle Research with Cosmics in the Abyss). ARCA's 3-d arrays will instrument 1 Gton of seawater, with the primary goal of detecting cosmic neutrinos with energies between several tens of GeV and PeV. Due to its position in the Northern Hemisphere, ARCA will provide an optimal view of the Southern sky including the Galactic Center. ORCA arrays are denser and its volume is smaller ( ~ few Mtons), optimized for the detection of atmospheric neutrinos in the 1 - 100 GeV. KM3NeT can also study low-energy neutrino astronomy, such as the MeV-scale core-collapse supernova, where each KM3NeT DOM acts as also as a detector.

* For the search of neutrinos via event reconstructions based on (causally coincident) lit-up DOMs, focusing on high energy neutrinos, such as astrophysical neutrinos, KM3NeT will be able to send/receive alerts from/to the multi-messenger community: 
 1. to receive external alerts, i.e. alerts generated by external experiments (e.g. gravitational waves alerts from LIGO/Virgo, neutrino alerts from other neutrino experiments) via GCN https://gcn.gsfc.nasa.gov/) and search for correlated neutrinos in KM3NeT. 
 2. to send neutrino alerts (to GCN) that we observe in KM3NeT, including multiplet alerts, possible astrophysical neutrinos, any correlated neutrinos we find in the above correlation search. The alerts will be used for external experiments to conduct their correlation search/follow-up.

* For the search of MeV core-collapse supernova neutrinos, each KM3NeT DOM acts as a detector. A CCSN neutrino interaction leads to higher counting rates of individual PMTs and an increase of the number of coincident lit-up PMTs in the same optical module. Its search entails a different method from the usual neutrino event reconstruction route, and it has a separate alert system called the SuperNova Early Warning System (https://snews.bnl.gov/), so the KM3NeT supernova alerts are not discussed in here. KM3NeT is already connected to SNEWS. 

### KM3NeT Alert Types

The alert types include: 

* MeV Core-Collapse Supernova alerts (SNEWS), already online currently
* Multiplet alerts: Multiple neutrinos from one source within some time window (this suggests a potential neutrino source)
* High-Energy Neutrino alerts. Potential neutrinos from astrophysical sources. (The higher the energy, the higher the probability of it being of astrophysical origin)
* Any neutrinos correlated with external alerts 
* Other alerts to be defined, or more subcategories divided from the High-Energy Neutrino alerts if necessary (e.g. track HE, cascade HE alerts)

### Alert Interfaces

The Alert receiving/sending is via the GCN (https://gcn.gsfc.nasa.gov/). The Alert data will be the neutrino candidates in VOEvent format, which is the standard data format for experiments to report and communicate their observed transient celestial events facilitating for follow-ups. The alert distribution is done via Comet (https://comet.transientskp.org/en/stable/index.html) which is an implementation of the VOEvent transportation protocol. 

(There are also others receivers that can be implemented but there are less convenient, e.g. the TNS for the optical alerts, the ZTF/LSST broker for the optical transients, the Fermi flare’s advocate for the Fermi blazar outbursts.)

For the public alerts, we will also submit the notice and circular (human in the loop) for the dissemination.

See more about VOEvent here:
* https://www.ivoa.net/documents/VOEvent/
* https://voevent.readthedocs.io/en/latest/index.html


### Alert data

The planned content for each neutrino alert includes:

* ID
* Detector (ARCA/ORCA)
* Type of alert triggers
* Multiplicity (i.e. number of events in given time and space windows)
* Flavor
* Energy
* IsRealAlert
* Time
* RA, DEC, Longitude, Latitude
* Error box 50%, 90% (TOC)
* Reconstruction quality
* Neutrino type (track/shower)
* Probability of neutrino
* Probability of astrophysical neutrino
* Ranking

 



